projected_phase_mesh — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# projected_phase_mesh

property ElectronicBandStructure.projected_phase_mesh

  projected phase mesh is a numpy array that stores each projection phases in a mesh grid. Shape = [n_kx,n_ky,n_kz,n_bands,n_spins,n_atoms,n_orbitals]

  Returns:

    np.ndarray – projected phase mesh is a numpy array that stores each projection phases in a mesh grid. Shape = [n_kx,n_ky,n_kz,n_bands,n_spins,n_atoms,n_orbitals]